@@ -59,6 +59,10 @@ def isLeapYear(y: int):
     leapYear = ((y % 4 == 0) and (y % 100 != 0) or (y % 400 == 0))
     return leapYear
 
+
+def parse_date(dateStr, dateFormat):
+    dt_obj = datetime.datetime.strptime(dateStr, dateFormat)
+    return dt_obj.day, dt_obj.month, dt_obj.year
 ###############################################################################
 # CREATE DATE COUNTER
 ###############################################################################
@@ -117,6 +121,13 @@ def calculateList():
                     gDateCounterList.append(-999)
 
 
+##############################################################################
+# The index in these functions is not the excel date index used as the 
+# internal representation of the date but the index of that date in the
+# padded date object used to store the dates in a way that allows for a
+# quick lookup. Do not confuse them as you will find they are out by months
+##############################################################################
+
 @njit(fastmath=True, cache=True)
 def dateIndex(d, m, y):
     idx = (y-gStartYear) * 12 * 31 + (m-1) * 31 + (d-1)
@@ -132,6 +143,7 @@ def dateFromIndex(idx):
     d = 1 + idx - (y-gStartYear) * 12 * 31 - (m-1) * 31
     return (d, m, y)
 
+###############################################################################
 
 @njit(fastmath=True, cache=True)
 def weekDay(dayCount):
@@ -155,17 +167,24 @@ class FinDate():
 
     ###########################################################################
 
-    def __init__(self,
-                 d: int,  # Day number in month with values from 1 to 31
-                 m: int,  # Month number where January = 1, ..., December = 12
-                 y: int):  # Year number which must be between 1900 and 2100
+    def __init__(self, *args):  # Year number which must be between 1900 and 2100
         ''' Create a date given a day of month, month and year. The arguments
         must be in the order of day (of month), month number and then the year.
-        The year must be a 4-digit number greater than or equal to 1900. '''
+        The year must be a 4-digit number greater than or equal to 1900.
+
+        Example Input:
+        start_date = FinDate('1-1-2018', '%d-%m-%Y')
+        start_date = FinDate(1, 1, 2018)
+        '''
 
         global gStartYear
         global gEndYear
 
+        if isinstance(args[0], str):
+           d, m, y = parse_date(args[0], args[1])
+        else:
+           d, m, y = args[0], args[1], args[2]
+
         # If the date has been entered as y, m, d we flip it to d, m, y
         if d >= gStartYear and d < gEndYear and y > 0 and y <= 31:
             tmp = y
@@ -290,25 +309,31 @@ class FinDate():
 
     ###########################################################################
 
-    def addWorkDays(self,
+    def addWeekDays(self,
                     numDays: int):
         ''' Returns a new date that is numDays working days after FinDate. Note
-        that only weekends are taken into account. Other Holidays are not. '''
+        that only weekends are taken into account. Other Holidays are not. If
+        you want to include regional holidays then use addBusinessDays from
+        the FinCalendar class. '''
+
+        # TODO: REMOVE DATETIME DEPENDENCE HERE
 
         if isinstance(numDays, int) is False:
             raise FinError("Num days must be an integer")
 
-        if numDays < 0:
-            raise FinError("Num days must be positive.")
-
         dt = datetime.date(self._y, self._m, self._d)
         d = dt.day
         m = dt.month
         y = dt.year
         newDt = FinDate(d, m, y)
 
+        s = +1
+        if numDays < 0:
+            numDays = -1 * numDays
+            s = -1
+
         while numDays > 0:
-            dt = dt + datetime.timedelta(days=1)
+            dt = dt + s * datetime.timedelta(days=1)
             d = dt.day
             m = dt.month
             y = dt.year
@@ -602,7 +627,8 @@ class FinDate():
         return dateStr
 
     ###########################################################################
-
+    # REMOVE THIS
+    
     def _print(self):
         ''' prints formatted string of the date. '''
         print(self)
@@ -626,7 +652,7 @@ def dailyWorkingDaySchedule(self,
     dt = startDate
     dateList.append(dt)
     while dt < endDate:
-        dt = dt.addWorkDays(1)
+        dt = dt.addWeekDays(1)
         dateList.append(dt)
 
     return dateList
