@@ -191,18 +191,21 @@ class FinDiscountCurve():
 ###############################################################################
 
     def swapRate(self,
-                 settlementDate: FinDate,
-                 maturityDate: FinDate,
+                 startDate: FinDate,
+                 maturityDate: (list, FinDate),
                  frequencyType=FinFrequencyTypes.ANNUAL,
                  dayCountType: FinDayCountTypes = FinDayCountTypes.THIRTY_E_360):
         ''' Calculate the swap rate to maturity date. This is the rate paid by
         a swap that has a price of par today. This is the same as a Libor swap
         rate except that we do not do any business day adjustments. '''
 
-        # Note that this function does not call the FinLiborSwap class to
+        # Note that this function does not call the FinIborSwap class to
         # calculate the swap rate since that will create a circular dependency.
         # I therefore recreate the actual calculation of the swap rate here.
 
+        if startDate < self._valuationDate:
+            raise FinError("Swap starts before the curve valuation date.")
+
         if isinstance(frequencyType, FinFrequencyTypes) is False:
             raise FinError("Invalid Frequency type.")
 
@@ -223,18 +226,19 @@ class FinDiscountCurve():
 
         for maturityDt in maturityDates:
 
-            schedule = FinSchedule(settlementDate,
+            schedule = FinSchedule(startDate,
                                    maturityDt,
                                    frequencyType)
 
             flowDates = schedule._generate()
-
+            flowDates[0] = startDate
+            
             dayCounter = FinDayCount(dayCountType)
             prevDt = flowDates[0]
             pv01 = 0.0
             df = 1.0
 
-            for nextDt in flowDates[1:]:
+            for nextDt in flowDates[1:]:                
                 df = self.df(nextDt)
                 alpha = dayCounter.yearFrac(prevDt, nextDt)[0]
                 pv01 += alpha * df
@@ -243,11 +247,11 @@ class FinDiscountCurve():
             if abs(pv01) < gSmall:
                 parRate = None
             else:
-                dfStart = self.df(settlementDate)
+                dfStart = self.df(startDate)
                 parRate = (dfStart - df) / pv01
 
             parRates.append(parRate)
-
+ 
         if isinstance(maturityDate, FinDate):
             return parRates[0]
         else:
