@@ -8,7 +8,7 @@ from math import exp, log, pi
 import numpy as np  # I USE NUMPY FOR EXP, LOG AND SQRT AS THEY HANDLE IMAGINARY PARTS
 
 from ..finutils.FinGlobalVariables import gDaysInYear
-from ..finutils.FinOptionTypes import FinOptionTypes
+from ..finutils.FinGlobalTypes import FinOptionTypes
 from ..finutils.FinMath import norminvcdf
 from ..finutils.FinError import FinError
 
@@ -195,9 +195,9 @@ class FinModelHeston():
                           schemeValue)
 
         if option._optionType == FinOptionTypes.EUROPEAN_CALL:
-            path_payoff = np.maximum(sPaths[:, -1] - K, 0)
+            path_payoff = np.maximum(sPaths[:, -1] - K, 0.0)
         elif option._optionType == FinOptionTypes.EUROPEAN_PUT:
-            path_payoff = np.maximum(K - sPaths[:, -1], 0)
+            path_payoff = np.maximum(K - sPaths[:, -1], 0.0)
         else:
             raise FinError("Unknown option type.")
 
