@@ -29,6 +29,7 @@ from ...finutils.FinFrequency import FinFrequency, FinFrequencyTypes
 from ...finutils.FinGlobalVariables import gDaysInYear
 from ...finutils.FinDayCount import FinDayCount, FinDayCountTypes
 from ...finutils.FinSchedule import FinSchedule
+from ...finutils.FinCalendar import FinCalendar
 from ...finutils.FinCalendar import FinCalendarTypes
 from ...finutils.FinCalendar import FinBusDayAdjustTypes
 from ...finutils.FinCalendar import FinDateGenRuleTypes
@@ -93,10 +94,9 @@ class FinBond(object):
                  frequencyType: FinFrequencyTypes,
                  accrualType: FinDayCountTypes,
                  faceAmount: float = 100.0):
-        ''' Create FinBond object by providing Maturity Date, Frequency,
-        coupon and the accrual convention type. No issue date is required as
-        we assume that the bond starts accruing before any settlement date and
-        so that the first coupon is a full coupon. This may change. '''
+        ''' Create FinBond object by providing the issue date, maturity Date,
+        coupon frequency, annualised coupon, the accrual convention type, face
+        amount and the number of ex-dividend days. '''
 
         checkArgumentTypes(self.__init__, locals())
 
@@ -116,7 +116,6 @@ class FinBond(object):
         self._flowDates = []
         self._flowAmounts = []
 
-        self._settlementDate = FinDate(1, 1, 1900)
         self._accruedInterest = None
         self._accruedDays = 0.0
         self._alpha = 0.0
@@ -127,8 +126,9 @@ class FinBond(object):
 ###############################################################################
 
     def _calculateFlowDates(self):
-        ''' Determine the bond cashflow payment dates. '''
-        # No need to generate flows if settlement date has not changed
+        ''' Determine the bond cashflow payment dates.'''
+
+        # This should only be called once from init 
 
         calendarType = FinCalendarTypes.NONE
         busDayRuleType = FinBusDayAdjustTypes.NONE
@@ -148,12 +148,10 @@ class FinBond(object):
 
         self._flowAmounts = [0.0]
 
-        for dt in self._flowDates[1:]:
+        for _ in self._flowDates[1:]:
            cpn = self._coupon / self._frequency
            self._flowAmounts.append(cpn)
     
-#        self._flowAmounts[-1] += 1.0
-
 ###############################################################################
 
     def fullPriceFromYTM(self,
@@ -229,7 +227,7 @@ class FinBond(object):
                   convention: FinYTMCalcType):
         ''' Calculate the principal value of the bond based on the face
         amount from its discount margin and making assumptions about the
-        future Libor rates. '''
+        future Ibor rates. '''
 
         fullPrice = self.fullPriceFromYTM(settlementDate, y, convention)
 
@@ -246,7 +244,7 @@ class FinBond(object):
         ''' Calculate the risk or dP/dy of the bond by bumping. This is also
         known as the DV01 in Bloomberg. '''
 
-        dy = 0.0001
+        dy = 0.0001 # 1 basis point
         p0 = self.fullPriceFromYTM(settlementDate, ytm - dy, convention)
         p2 = self.fullPriceFromYTM(settlementDate, ytm + dy, convention)
         durn = -(p2 - p0) / dy / 2.0
@@ -413,11 +411,18 @@ class FinBond(object):
 
 ###############################################################################
 
-    def calcAccruedInterest(self, settlementDate: FinDate):
+    def calcAccruedInterest(self, 
+                            settlementDate: FinDate,
+                            numExDividendDays: int = 0, 
+                            calendarType: FinCalendarTypes = FinCalendarTypes.WEEKEND):
         ''' Calculate the amount of coupon that has accrued between the
         previous coupon date and the settlement date. Note that for some day
         count schemes (such as 30E/360) this is not actually the number of days
-        between the previous coupon payment date and settlement date. '''
+        between the previous coupon payment date and settlement date. If the
+        bond trades with ex-coupon dates then you need to supply the number of
+        days before the coupon date the ex-coupon date is. You can specify the
+        calendar to be used - NONE means only calendar days, WEEKEND is only 
+        weekends or you can specify a country calendar for business days.'''
 
         numFlows = len(self._flowDates)
 
@@ -430,13 +435,18 @@ class FinBond(object):
                 self._pcd = self._flowDates[iFlow-1]
                 self._ncd = self._flowDates[iFlow]
                 break
-        
+
         dc = FinDayCount(self._accrualType)
+        cal = FinCalendar(calendarType)
+        exDividendDate = cal.addBusinessDays(self._ncd, -numExDividendDays)
 
         (accFactor, num, _) = dc.yearFrac(self._pcd,
-                                          settlementDate,
-                                          self._ncd, 
-                                          self._frequency)
+                                            settlementDate,
+                                            self._ncd, 
+                                            self._frequency)
+        
+        if settlementDate > exDividendDate:
+            accFactor = accFactor - 1.0 / self._frequency
 
         self._alpha = 1.0 - accFactor * self._frequency
         self._accruedInterest = accFactor * self._faceAmount * self._coupon
@@ -457,15 +467,15 @@ class FinBond(object):
             swapFloatBusDayAdjustRuleType=FinBusDayAdjustTypes.FOLLOWING,
             swapFloatDateGenRuleType=FinDateGenRuleTypes.BACKWARD):
         ''' Calculate the par asset swap spread of the bond. The discount curve
-        is a Libor curve that is passed in. This function is vectorised with
+        is a Ibor curve that is passed in. This function is vectorised with
         respect to the clean price. '''
 
         cleanPrice = np.array(cleanPrice)
         self.calcAccruedInterest(settlementDate)
         accruedAmount = self._accruedInterest * self._par / self._faceAmount
         bondPrice = cleanPrice + accruedAmount
-        # Calculate the price of the bond discounted on the Libor curve
-        pvLibor = 0.0
+        # Calculate the price of the bond discounted on the Ibor curve
+        pvIbor = 0.0
         prevDate = self._pcd
 
         for dt in self._flowDates[1:]:
@@ -473,9 +483,9 @@ class FinBond(object):
             # coupons paid on a settlement date are included
             if dt >= settlementDate:
                 df = discountCurve.df(dt)
-                pvLibor += df * self._coupon / self._frequency
+                pvIbor += df * self._coupon / self._frequency
 
-        pvLibor += df * self._redemption
+        pvIbor += df * self._redemption
 
         # Calculate the PV01 of the floating leg of the asset swap
         # I assume here that the coupon starts accruing on the settlement date
@@ -497,7 +507,7 @@ class FinBond(object):
             pv01 = pv01 + yearFrac * df
             prevDate = dt
 
-        asw = (pvLibor - bondPrice/self._par) / pv01
+        asw = (pvIbor - bondPrice/self._par) / pv01
         return asw
 
 ###############################################################################
@@ -520,7 +530,7 @@ class FinBond(object):
             if dt >= settlementDate:
                 t = (dt - settlementDate) / gDaysInYear
                 df = discountCurve.df(dt)
-                # determine the Libor implied zero rate
+                # determine the Ibor implied zero rate
                 r = f * (np.power(df, -1.0 / t / f) - 1.0)
                 # determine the OAS adjusted zero rate
                 df_adjusted = np.power(1.0 + (r + oas)/f, -t * f)
