@@ -1,10 +1,13 @@
-# -*- coding: utf-8 -*-
+##############################################################################
+# Copyright (C) 2018, 2019, 2020 Dominic O'Kane
+##############################################################################
 
 # TODO - MUST ADD ACCRUED INTEREST TO MODEL!!!!
 
 from math import exp, sqrt
 from numba import njit
 import numpy as np
+from typing import List
 
 from ...finutils.FinDate import FinDate
 from ...finutils.FinError import FinError
@@ -12,86 +15,88 @@ from ...finutils.FinFrequency import FinFrequency, FinFrequencyTypes
 from ...finutils.FinMath import testMonotonicity
 from ...finutils.FinGlobalVariables import gDaysInYear
 from ...finutils.FinDayCount import FinDayCount, FinDayCountTypes
+from ...finutils.FinHelperFunctions import labelToString, checkArgumentTypes
 
 from ...finutils.FinSchedule import FinSchedule
 from ...finutils.FinCalendar import FinCalendarTypes
-from ...finutils.FinCalendar import FinDayAdjustTypes
+from ...finutils.FinCalendar import FinBusDayAdjustTypes
 from ...finutils.FinCalendar import FinDateGenRuleTypes
 
-from ...market.curves.FinInterpolate import FinInterpMethods, uinterpolate
+from ...market.curves.FinDiscountCurve import FinDiscountCurve
+from ...market.curves.FinInterpolate import FinInterpTypes, _uinterpolate
 
 ###############################################################################
 
 
 @njit(fastmath=True, cache=True)
-def valueConvertible(tmat,
-                     face,
-                     couponTimes,
-                     couponFlows,
-                     callTimes,
-                     callPrices,
-                     putTimes,
-                     putPrices,
-                     convRatio,
-                     startConvertTime,
-                     # Market inputs
-                     stockPrice,
-                     dfTimes,
-                     dfValues,
-                     dividendTimes,
-                     dividendYields,
-                     stockVolatility,
-                     creditSpread,
-                     recRate,
-                     # Tree details
-                     numStepsPerYear):
+def _valueConvertible(tmat,
+                      faceAmount,
+                      couponTimes,
+                      couponFlows,
+                      callTimes,
+                      callPrices,
+                      putTimes,
+                      putPrices,
+                      convRatio,
+                      startConvertTime,
+                      # Market inputs
+                      stockPrice,
+                      dfTimes,
+                      dfValues,
+                      dividendTimes,
+                      dividendYields,
+                      stockVolatility,
+                      creditSpread,
+                      recRate,
+                      # Tree details
+                      numStepsPerYear):
 
-    interp = FinInterpMethods.FLAT_FORWARDS.value
+    interp = FinInterpTypes.FLAT_FORWARDS.value
 
     if len(couponTimes) > 0:
         if couponTimes[-1] > tmat:
-            raise ValueError("Coupon after maturity")
+            raise FinError("Coupon after maturity")
 
     if len(callTimes) > 0:
         if callTimes[-1] > tmat:
-            raise ValueError("Call times after maturity")
+            raise FinError("Call times after maturity")
 
     if len(putTimes) > 0:
         if putTimes[-1] > tmat:
-            raise ValueError("Put times after maturity")
+            raise FinError("Put times after maturity")
 
     if len(dfTimes) > 0:
         if dfTimes[-1] > tmat:
-            raise ValueError("Discount times after maturity")
+            raise FinError("Discount times after maturity")
 
     if len(dividendTimes) > 0:
         if dividendTimes[-1] > tmat:
-            raise ValueError("Dividend times after maturity")
+            raise FinError("Dividend times after maturity")
 
     if creditSpread < 0.0:
-        raise ValueError("Credit spread negative.")
+        raise FinError("Credit spread negative.")
 
     if recRate < 0.0 or recRate > 1.0:
-        raise ValueError("Recovery rate should be between 0 and 1.")
+        raise FinError("Recovery rate should be between 0 and 1.")
 
     if stockVolatility < 0.0:
-        raise ValueError("Stock volatility cannot be negative.")
+        raise FinError("Stock volatility cannot be negative.")
 
     if numStepsPerYear < 1:
-        raise ValueError("Num Steps per year must more than 1.")
+        raise FinError("Num Steps per year must more than 1.")
 
     if len(dividendTimes) > 0.0:
         if dividendTimes[-1] > tmat:
-            raise ValueError("Last dividend is after bond maturity.")
+            raise FinError("Last dividend is after bond maturity.")
 
     if recRate > 0.999 or recRate < 0.0:
-        raise ValueError("Recovery rate must be between 0 and 0.999.")
+        raise FinError("Recovery rate must be between 0 and 0.999.")
 
     numTimes = int(numStepsPerYear * tmat) + 1  # add one for today time 0
     numTimes = numStepsPerYear  # XXXXXXXX!!!!!!!!!!!!!!!!!!!!!
-    
+
     if numTimes < 5:
-        raise ValueError("Numsteps must be greater than 5.")
+        raise FinError("Numsteps must be greater than 5.")
 
     numLevels = numTimes
 
@@ -101,7 +106,7 @@ def valueConvertible(tmat,
     treeTimes = np.linspace(0.0, tmat, numTimes)
     treeDfs = np.zeros(numTimes)
     for i in range(0, numTimes):
-        df = uinterpolate(treeTimes[i], dfTimes, dfValues, interp)
+        df = _uinterpolate(treeTimes[i], dfTimes, dfValues, interp)
         treeDfs[i] = df
 
     h = creditSpread/(1.0 - recRate)
@@ -114,14 +119,14 @@ def valueConvertible(tmat,
         flowTime = couponTimes[i]
         n = int(round(flowTime/dt, 0))
         treeTime = treeTimes[n]
-        df_flow = uinterpolate(flowTime, dfTimes, dfValues, interp)
+        df_flow = _uinterpolate(flowTime, dfTimes, dfValues, interp)
         df_flow *= exp(-h*flowTime)
-        df_tree = uinterpolate(treeTime, dfTimes, dfValues, interp)
+        df_tree = _uinterpolate(treeTime, dfTimes, dfValues, interp)
         df_tree *= exp(-h*treeTime)
         treeFlows[n] += couponFlows[i] * 1.0 * df_flow / df_tree
 
     # map call onto tree - must have no calls at high value
-    treeCallValue = np.ones(numTimes) * face * 1000.0
+    treeCallValue = np.ones(numTimes) * faceAmount * 1000.0
     numCalls = len(callTimes)
     for i in range(0, numCalls):
         callTime = callTimes[i]
@@ -194,14 +199,14 @@ def valueConvertible(tmat,
 #        n_min = r*r / stockVolatility / stockVolatility
 
     if np.any(treeProbsUp > 1.0):
-        raise ValueError("pUp > 1.0. Increase time steps.")
+        raise FinError("pUp > 1.0. Increase time steps.")
 
     ###########################################################################
     # work backwards by first setting values at bond maturity date
     ###########################################################################
 
     flow = treeFlows[numTimes-1]
-    bulletPV = (1.0 + flow) * face
+    bulletPV = (1.0 + flow) * faceAmount
     for iNode in range(0, numLevels):
         convValue = treeConvertValue[numTimes-1, iNode]
         treeConvBondValue[numTimes-1, iNode] = max(bulletPV, convValue)
@@ -221,14 +226,14 @@ def valueConvertible(tmat,
             futValueUp = treeConvBondValue[iTime+1, iNode+1]
             futValueDn = treeConvBondValue[iTime+1, iNode]
             hold = pUp * futValueUp + pDn * futValueDn  # pUp already embeds Q
-            holdPV = df * hold + pDef * df * recRate * face + flow * face
+            holdPV = df * hold + pDef * df * recRate * faceAmount + flow * faceAmount
             conv = treeConvertValue[iTime, iNode]
             value = min(max(holdPV, conv, put), call)
             treeConvBondValue[iTime, iNode] = value
 
         bulletPV = df * bulletPV * survProb
-        bulletPV += pDef * df * recRate * face
-        bulletPV += flow * face
+        bulletPV += pDef * df * recRate * faceAmount
+        bulletPV += flow * faceAmount
 
     price = treeConvBondValue[0, 0]
     delta = (treeConvBondValue[1, 1] - treeConvBondValue[1, 0]) / \
@@ -254,28 +259,24 @@ class FinBondConvertible(object):
     the credit quality of the issuer and the level of interest rates.'''
 
     def __init__(self,
-                 maturityDate,  # bond maturity date
-                 coupon,  # annual coupon
-                 frequencyType,  # coupon frequency type
-                 startConvertDate,  # date after which conversion is possible
-                 conversionRatio,  # number of shares per face of notional
-                 callDates,  # list of call dates
-                 callPrices,  # list of call prices
-                 putDates,  # list of put dates
-                 putPrices,  # list of put prices
-                 accrualType,  # day count type for accrued interest
-                 face=100.0  # face amount
-                 ):
-        ''' Create FinBond object by providing Maturity Date, Frequency,
-        coupon and the accrual convention type. '''
+                 maturityDate: FinDate,  # bond maturity date
+                 coupon: float,  # annual coupon
+                 frequencyType: FinFrequencyTypes,  # coupon frequency type
+                 startConvertDate: FinDate,  # conversion starts on this date
+                 conversionRatio: float,  # num shares per face of notional
+                 callDates: List[FinDate],  # list of call dates
+                 callPrices: List[float],  # list of call prices
+                 putDates: List[FinDate],  # list of put dates
+                 putPrices: List[float],  # list of put prices
+                 accrualType: FinDayCountTypes,  # day count type for accrued
+                 faceAmount: float = 100.0):  # face amount
+        ''' Create FinBondConvertible object by providing the bond Maturity
+        date, coupon, frequency type, accrual convention type and then all of
+        the details regarding the conversion option including the list of the
+        call and put dates and the corresponding list of call and put prices. 
+        '''
 
-        if frequencyType not in FinFrequencyTypes:
-            raise FinError("Invalid Frequency:" + str(frequencyType))
-            return
-
-        if accrualType not in FinDayCountTypes:
-            raise FinError("Unknown Day Count Accrued Convention type " +
-                           str(accrualType))
+        checkArgumentTypes(self.__init__, locals())
 
         if startConvertDate > maturityDate:
             raise FinError("Start convert date is after bond maturity.")
@@ -300,11 +301,11 @@ class FinBondConvertible(object):
 
         if len(putDates) > 0:
             if putDates[-1] > maturityDate:
-                raise ValueError("Last put is after bond maturity.")
+                raise FinError("Last put is after bond maturity.")
 
         if len(callDates) > 0:
             if callDates[-1] > maturityDate:
-                raise ValueError("Last call is after bond maturity.")
+                raise FinError("Last call is after bond maturity.")
 
         self._startConvertDate = startConvertDate
 
@@ -312,17 +313,22 @@ class FinBondConvertible(object):
             raise FinError("Conversion ratio is negative.")
 
         self._conversionRatio = conversionRatio
+        self._faceAmount = faceAmount
 
-        self._face = face
-        self._settlementDate = FinDate(1900, 1, 1)
+        self._settlementDate = FinDate(1, 1, 1900)
         ''' I do not determine cashflow dates as I do not want to require
         users to supply the issue date and without that I do not know how
         far to go back in the cashflow date schedule. '''
 
-##########################################################################
+        self._accruedInterest = None
+        self._accruedDays = 0.0
+        self._alpha = 0.0
+       
+###############################################################################
 
-    def calculateFlowDates(self, settlementDate):
-        ''' Determine the bond cashflow payment dates. '''
+    def _calculateFlowDates(self,
+                            settlementDate: FinDate):
+        ''' Determine the convertible bond cashflow payment dates. '''
 
         # No need to generate flows if settlement date has not changed
         if settlementDate == self._settlementDate:
@@ -330,7 +336,7 @@ class FinBondConvertible(object):
 
         self._settlementDate = settlementDate
         calendarType = FinCalendarTypes.NONE
-        busDayRuleType = FinDayAdjustTypes.NONE
+        busDayRuleType = FinBusDayAdjustTypes.NONE
         dateGenRuleType = FinDateGenRuleTypes.BACKWARD
 
         self._flowDates = FinSchedule(settlementDate,
@@ -338,25 +344,24 @@ class FinBondConvertible(object):
                                       self._frequencyType,
                                       calendarType,
                                       busDayRuleType,
-                                      dateGenRuleType).generate()
+                                      dateGenRuleType)._generate()
 
         self._pcd = self._flowDates[0]
         self._ncd = self._flowDates[1]
-        self._accruedInterest(settlementDate)
+        self.calcAccruedInterest(settlementDate)
 
-##########################################################################
+###############################################################################
 
     def value(self,
-              settlementDate,
-              stockPrice,
-              stockVolatility,
-              dividendDates,
-              dividendYields,
-              discountCurve,
-              creditSpread,
-              recoveryRate = 0.40,
-              numStepsPerYear = 100):
-
+              settlementDate: FinDate,
+              stockPrice: float,
+              stockVolatility: float,
+              dividendDates: List[FinDate],
+              dividendYields: List[float],
+              discountCurve: FinDiscountCurve,
+              creditSpread: float,
+              recoveryRate: float = 0.40,
+              numStepsPerYear: int = 100):
         '''
         A binomial tree valuation model for a convertible bond that captures
         the embedded equity option due to the existence of a conversion option
@@ -384,7 +389,7 @@ class FinBondConvertible(object):
         if stockVolatility <= 0.0:
             stockVolatility = 1e-10  # Avoid overflows in delta calc
 
-        self.calculateFlowDates(settlementDate)
+        self._calculateFlowDates(settlementDate)
         tmat = (self._maturityDate - settlementDate) / gDaysInYear
         if tmat <= 0.0:
             raise FinError("Maturity must not be on or before the value date.")
@@ -428,13 +433,13 @@ class FinBondConvertible(object):
         putPrices = np.array(self._putPrices)
 
         if np.any(putTimes > tmat):
-            raise ValueError("No put times can be after the maturity date.")
+            raise FinError("No put times can be after the maturity date.")
 
         if np.any(putTimes <= 0.0):
-            raise ValueError("No put times can be on or before value date.")
+            raise FinError("No put times can be on or before value date.")
 
         if len(dividendYields) != len(dividendDates):
-            raise ValueError("Number of dividend yields and dates not same.")
+            raise FinError("Number of dividend yields and dates not same.")
 
         dividendTimes = []
         for dt in dividendDates:
@@ -449,70 +454,70 @@ class FinBondConvertible(object):
 
         discountFactors = []
         for t in couponTimes:
-            df = discountCurve.df(t)
+            df = discountCurve._df(t)
             discountFactors.append(df)
 
         discountTimes = np.array(couponTimes)
         discountFactors = np.array(discountFactors)
 
         if testMonotonicity(couponTimes) is False:
-            raise ValueError("Coupon times not monotonic")
+            raise FinError("Coupon times not monotonic")
 
         if testMonotonicity(callTimes) is False:
-            raise ValueError("Coupon times not monotonic")
+            raise FinError("Coupon times not monotonic")
 
         if testMonotonicity(putTimes) is False:
-            raise ValueError("Coupon times not monotonic")
+            raise FinError("Coupon times not monotonic")
 
         if testMonotonicity(discountTimes) is False:
-            raise ValueError("Coupon times not monotonic")
+            raise FinError("Coupon times not monotonic")
 
         if testMonotonicity(dividendTimes) is False:
-            raise ValueError("Coupon times not monotonic")
+            raise FinError("Coupon times not monotonic")
 
-        v1 = valueConvertible(tmat,
-                              self._face,
-                              couponTimes,
-                              couponFlows,
-                              callTimes,
-                              callPrices,
-                              putTimes,
-                              putPrices,
-                              self._conversionRatio,
-                              tconv,
-                              # Market inputs
-                              stockPrice,
-                              discountTimes,
-                              discountFactors,
-                              dividendTimes,
-                              dividendYields,
-                              stockVolatility,
-                              creditSpread,
-                              recoveryRate,
-                              # Tree details
-                              numStepsPerYear)
+        v1 = _valueConvertible(tmat,
+                               self._faceAmount,
+                               couponTimes,
+                               couponFlows,
+                               callTimes,
+                               callPrices,
+                               putTimes,
+                               putPrices,
+                               self._conversionRatio,
+                               tconv,
+                               # Market inputs
+                               stockPrice,
+                               discountTimes,
+                               discountFactors,
+                               dividendTimes,
+                               dividendYields,
+                               stockVolatility,
+                               creditSpread,
+                               recoveryRate,
+                               # Tree details
+                               numStepsPerYear)
 
-        v2 = valueConvertible(tmat,
-                              self._face,
-                              couponTimes,
-                              couponFlows,
-                              callTimes,
-                              callPrices,
-                              putTimes,
-                              putPrices,
-                              self._conversionRatio,
-                              tconv,
-                              # Market inputs
-                              stockPrice,
-                              discountTimes,
-                              discountFactors,
-                              dividendTimes,
-                              dividendYields,
-                              stockVolatility,
-                              creditSpread,
-                              recoveryRate,
-                              # Tree details
-                              numStepsPerYear + 1)
+        v2 = _valueConvertible(tmat,
+                               self._faceAmount,
+                               couponTimes,
+                               couponFlows,
+                               callTimes,
+                               callPrices,
+                               putTimes,
+                               putPrices,
+                               self._conversionRatio,
+                               tconv,
+                               # Market inputs
+                               stockPrice,
+                               discountTimes,
+                               discountFactors,
+                               dividendTimes,
+                               dividendYields,
+                               stockVolatility,
+                               creditSpread,
+                               recoveryRate,
+                               # Tree details
+                               numStepsPerYear + 1)
 
         cbprice = (v1[0] + v2[0])/2.0
         bond = (v1[1] + v2[1])/2.0
@@ -525,64 +530,88 @@ class FinBondConvertible(object):
 
         return results
 
-##########################################################################
+###############################################################################
 
-    def accruedDays(self, settlementDate):
+    def accruedDays(self, 
+                    settlementDate: FinDate):
         ''' Calculate number days from previous coupon date to settlement.'''
-        self.calculateFlowDates(settlementDate)
+        self._calculateFlowDates(settlementDate)
 
         if len(self._flowDates) <= 2:
             raise FinError("Accrued interest - not enough flow dates.")
 
-        return settlementDate - self.pcd(settlementDate)
+        return settlementDate - self._pcd
 
-##########################################################################
+###############################################################################
 
-    def _accruedInterest(self, settlementDate):
+    def calcAccruedInterest(self,
+                            settlementDate: FinDate):
         ''' Calculate the amount of coupon that has accrued between the
         previous coupon date and the settlement date. '''
 
-        self.calculateFlowDates(settlementDate)
+        if settlementDate != self._settlementDate:
+            self._calculateFlowDates(settlementDate)
 
         if len(self._flowDates) == 0:
             raise FinError("Accrued interest - not enough flow dates.")
 
         dc = FinDayCount(self._accrualType)
 
-        if self._accrualType == FinDayCountTypes.ACT_ACT_ICMA:
-            accFactor = dc.yearFrac(self._pcd, settlementDate, self._ncd)
-            alpha = 1.0 - accFactor
-            accFactor = accFactor/self._frequency
-        else:
-            accFactor = dc.yearFrac(self._pcd, settlementDate)
-            alpha = 1.0 - accFactor
+        (accFactor, num, _) = dc.yearFrac(self._pcd,
+                                          settlementDate,
+                                          self._ncd, 
+                                          self._frequency)
 
-        self._accrued = accFactor * self._face * self._coupon
-        self._alpha = alpha
-        self._accruedDays = settlementDate - self._pcd
+        self._alpha = 1.0 - accFactor * self._frequency
 
-##########################################################################
+        self._accrued = accFactor * self._faceAmount * self._coupon
+        self._accruedDays = num
+        return self._accruedInterest
 
-    def currentYield(self, cleanPrice):
+###############################################################################
+
+    def currentYield(self,
+                     cleanPrice: float):
         ''' Calculate the current yield of the bond which is the
         coupon divided by the clean price (not the full price)'''
 
-        y = self._coupon * self._face / cleanPrice
+        y = self._coupon * self._faceAmount / cleanPrice
         return y
 
-##########################################################################
+###############################################################################
 
-    def print(self):
+    def __repr__(self):
         ''' Print a list of the unadjusted coupon payment dates used in
         analytic calculations for the bond. '''
-        print("Maturity Date:", self._maturityDate)
-        print("Coupon:", self._coupon)
-        print("Frequency:", self._frequencyType)
-        print("Accrual:", self._accrualType)
+        s = labelToString("OBJECT TYPE", type(self).__name__)
+        s += labelToString("MATURITY DATE", self._maturityDate)
+        s += labelToString("COUPON", self._coupon)
+        s += labelToString("FREQUENCY", self._frequencyType)
+        s += labelToString("ACCRUAL TYPE", self._accrualType)
+        s += labelToString("FACE AMOUNT", self._faceAmount)
+        s += labelToString("CONVERSION RATIO", self._conversionRatio)
+        s += labelToString("START CONVERT DATE", self._startConvertDate)
+        s += labelToString("CALL", "DATES")
 
-##########################################################################
+        for i in range(0, len(self._callDates)):
+            s += labelToString(self._callDates[i],
+                               self._callPrices[i])
 
+        s += labelToString("PUT", "DATES")
 
+        for i in range(0, len(self._putDates)):
+            s += labelToString(self._putDates[i],
+                               self._putPrices[i])
+
+        return s
+
+###############################################################################
+
+    def _print(self):
+        ''' Simple print function for backward compatibility. '''
+        print(self)
+
+###############################################################################
 ###############################################################################
 ###############################################################################
 ###############################################################################
