@@ -39,8 +39,8 @@ def _riskyPV01_NUMBA(teff,
                      accrualFactorPCDToNow,
                      paymentTimes,
                      yearFracs,
-                     npLiborTimes,
-                     npLiborValues,
+                     npIborTimes,
+                     npIborValues,
                      npSurvTimes,
                      npSurvValues,
                      pv01Method):
@@ -61,7 +61,7 @@ def _riskyPV01_NUMBA(teff,
     # taking into account what coupon has already accrued and what has not
     qeff = _uinterpolate(teff, npSurvTimes, npSurvValues, method)
     q1 = _uinterpolate(tncd, npSurvTimes, npSurvValues, method)
-    z1 = _uinterpolate(tncd, npLiborTimes, npLiborValues, method)
+    z1 = _uinterpolate(tncd, npIborTimes, npIborValues, method)
 
     # this is the part of the coupon accrued from previous coupon date to now
     # accrualFactorPCDToNow = dayCount.yearFrac(pcd,teff)
@@ -85,7 +85,7 @@ def _riskyPV01_NUMBA(teff,
         t2 = paymentTimes[it]
 
         q2 = _uinterpolate(t2, npSurvTimes, npSurvValues, method)
-        z2 = _uinterpolate(t2, npLiborTimes, npLiborValues, method)
+        z2 = _uinterpolate(t2, npIborTimes, npIborValues, method)
 
         accrualFactor = yearFracs[it]
 
@@ -126,8 +126,8 @@ def _riskyPV01_NUMBA(teff,
               float64, int64, int64), fastmath=True, cache=True)
 def _protectionLegPV_NUMBA(teff,
                            tmat,
-                           npLiborTimes,
-                           npLiborValues,
+                           npIborTimes,
+                           npIborValues,
                            npSurvTimes,
                            npSurvValues,
                            contractRecovery,
@@ -139,7 +139,7 @@ def _protectionLegPV_NUMBA(teff,
     method = FinInterpTypes.FLAT_FORWARDS.value
     dt = (tmat - teff) / numStepsPerYear
     t = teff
-    z1 = _uinterpolate(t, npLiborTimes, npLiborValues, method)
+    z1 = _uinterpolate(t, npIborTimes, npIborValues, method)
     q1 = _uinterpolate(t, npSurvTimes, npSurvValues, method)
 
     protPV = 0.0
@@ -150,7 +150,7 @@ def _protectionLegPV_NUMBA(teff,
         for _ in range(0, numStepsPerYear):
 
             t = t + dt
-            z2 = _uinterpolate(t, npLiborTimes, npLiborValues, method)
+            z2 = _uinterpolate(t, npIborTimes, npIborValues, method)
             q2 = _uinterpolate(t, npSurvTimes, npSurvValues, method)
             # This needs to be updated to handle small h+r
             h12 = -log(q2 / q1) / dt
@@ -167,7 +167,7 @@ def _protectionLegPV_NUMBA(teff,
         for _ in range(0, numStepsPerYear):
 
             t += dt
-            z2 = _uinterpolate(t, npLiborTimes, npLiborValues, method)
+            z2 = _uinterpolate(t, npIborTimes, npIborValues, method)
             q2 = _uinterpolate(t, npSurvTimes, npSurvValues, method)
             dq = q1 - q2
             dprotPV = 0.5 * (z1 + z2) * dq
