@@ -14,7 +14,7 @@ from ...models.FinGBMProcess import FinGBMProcess
 from ...products.equity.FinEquityOption import FinEquityOption
 from ...finutils.FinHelperFunctions import labelToString, checkArgumentTypes
 from ...market.curves.FinDiscountCurve import FinDiscountCurve
-from ...finutils.FinOptionTypes import FinOptionTypes
+from ...finutils.FinGlobalTypes import FinOptionTypes
 
 ##########################################################################
 # TODO: Attempt control variate adjustment to monte carlo
@@ -218,12 +218,12 @@ class FinEquityFixedLookbackOption(FinEquityOption):
         if optionType == FinOptionTypes.EUROPEAN_CALL:
             SMax = np.max(Sall, axis=1)
             smaxs = np.ones(numPaths) * smax
-            payoff = np.maximum(SMax - k, 0)
+            payoff = np.maximum(SMax - k, 0.0)
             payoff = np.maximum(payoff, smaxs - k)
         elif optionType == FinOptionTypes.EUROPEAN_PUT:
             SMin = np.min(Sall, axis=1)
             smins = np.ones(numPaths) * smin
-            payoff = np.maximum(k - SMin, 0)
+            payoff = np.maximum(k - SMin, 0.0)
             payoff = np.maximum(payoff, k - smins)
         else:
             raise FinError("Unknown lookback option type:" + str(optionType))
