@@ -14,7 +14,7 @@ from ...models.FinGBMProcess import FinGBMProcess
 from ...products.equity.FinEquityOption import FinEquityOption
 from ...finutils.FinHelperFunctions import labelToString, checkArgumentTypes
 from ...market.curves.FinDiscountCurve import FinDiscountCurve
-from ...finutils.FinOptionTypes import FinOptionTypes
+from ...finutils.FinGlobalTypes import FinOptionTypes
 
 ##########################################################################
 # TODO: Attempt control variate adjustment to monte carlo
@@ -182,11 +182,11 @@ class FinEquityFloatLookbackOption(FinEquityOption):
         if optionType == FinOptionTypes.EUROPEAN_CALL:
             SMin = np.min(Sall, axis=1)
             SMin = np.minimum(SMin, smin)
-            payoff = np.maximum(Sall[:, -1] - SMin, 0)
+            payoff = np.maximum(Sall[:, -1] - SMin, 0.0)
         elif optionType == FinOptionTypes.EUROPEAN_PUT:
             SMax = np.max(Sall, axis=1)
             SMax = np.maximum(SMax, smax)
-            payoff = np.maximum(SMax - Sall[:, -1], 0)
+            payoff = np.maximum(SMax - Sall[:, -1], 0.0)
         else:
             raise FinError("Unknown lookback option type:" + str(optionType))
 
