@@ -15,7 +15,7 @@ from ...models.FinGBMProcess import FinGBMProcess
 ###############################################################################
 
 from ...products.fx.FinFXOption import FinFXOption
-from ...finutils.FinOptionTypes import FinOptionTypes
+from ...finutils.FinGlobalTypes import FinOptionTypes
 from ...finutils.FinHelperFunctions import checkArgumentTypes
 from ...finutils.FinDate import FinDate
 from ...finutils.FinError import FinError
@@ -188,9 +188,9 @@ class FinFXBasketOption(FinFXOption):
                                     seed)
 
         if self._optionType == FinOptionTypes.EUROPEAN_CALL:
-            payoff = np.maximum(np.mean(Sall, axis=1) - K, 0)
+            payoff = np.maximum(np.mean(Sall, axis=1) - K, 0.0)
         elif self._optionType == FinOptionTypes.EUROPEAN_PUT:
-            payoff = np.maximum(K - np.mean(Sall, axis=1), 0)
+            payoff = np.maximum(K - np.mean(Sall, axis=1), 0.0)
         else:
             raise FinError("Unknown option type.")
 
