@@ -12,7 +12,7 @@ from ...finutils.FinError import FinError
 from ...models.FinGBMProcess import FinGBMProcess
 from ...finutils.FinHelperFunctions import labelToString, checkArgumentTypes
 from ...finutils.FinDate import FinDate
-from ...finutils.FinOptionTypes import FinOptionTypes
+from ...finutils.FinGlobalTypes import FinOptionTypes
 from ...market.curves.FinDiscountCurve import FinDiscountCurve
 
 ##########################################################################
@@ -222,12 +222,12 @@ class FinFXFixedLookbackOption():
         if optionType == FinOptionTypes.EUROPEAN_CALL:
             SMax = np.max(Sall, axis=1)
             smaxs = np.ones(numPaths) * smax
-            payoff = np.maximum(SMax - k, 0)
+            payoff = np.maximum(SMax - k, 0.0)
             payoff = np.maximum(payoff, smaxs - k)
         elif optionType == FinOptionTypes.EUROPEAN_PUT:
             SMin = np.min(Sall, axis=1)
             smins = np.ones(numPaths) * smin
-            payoff = np.maximum(k - SMin, 0)
+            payoff = np.maximum(k - SMin, 0.0)
             payoff = np.maximum(payoff, k - smins)
         else:
             raise FinError("Unknown lookback option type:" + str(optionType))
