@@ -11,7 +11,7 @@ from ...finutils.FinDate import FinDate
 from ...finutils.FinMath import nprime
 from ...finutils.FinGlobalVariables import gDaysInYear
 from ...finutils.FinError import FinError
-from ...finutils.FinOptionTypes import FinOptionTypes
+from ...finutils.FinGlobalTypes import FinOptionTypes
 from ...products.fx.FinFXModelTypes import FinFXModel
 from ...products.fx.FinFXModelTypes import FinFXModelBlackScholes
 from ...products.fx.FinFXModelTypes import FinFXModelSABR
@@ -156,7 +156,7 @@ class FinFXVanillaOption():
 
         checkArgumentTypes(self.__init__, locals())
 
-        deliveryDate = expiryDate.addWorkDays(spotDays)
+        deliveryDate = expiryDate.addWeekDays(spotDays)
 
         ''' The FX rate the price in domestic currency ccy2 of a single unit
         of the foreign currency which is ccy1. For example EURUSD of 1.3 is the
@@ -210,7 +210,7 @@ class FinFXVanillaOption():
         price in domestic of one unit of foreign currency. '''
 
         if type(valueDate) == FinDate:
-            spotDate = valueDate.addWorkDays(self._spotDays)
+            spotDate = valueDate.addWeekDays(self._spotDays)
             tdel = (self._deliveryDate - spotDate) / gDaysInYear
             texp = (self._expiryDate - valueDate) / gDaysInYear
         else:
@@ -360,7 +360,7 @@ class FinFXVanillaOption():
         by Iain Clark, published by Wiley Finance. '''
 
         if type(valueDate) == FinDate:
-            spotDate = valueDate.addWorkDays(self._spotDays)
+            spotDate = valueDate.addWeekDays(self._spotDays)
             tdel = (self._deliveryDate - spotDate) / gDaysInYear
             texp = (self._expiryDate - valueDate) / gDaysInYear
         else:
@@ -671,11 +671,11 @@ class FinFXVanillaOption():
         s_2 = s / m
 
         if self._optionType == FinOptionTypes.EUROPEAN_CALL:
-            payoff_a_1 = np.maximum(s_1 - K, 0)
-            payoff_a_2 = np.maximum(s_2 - K, 0)
+            payoff_a_1 = np.maximum(s_1 - K, 0.0)
+            payoff_a_2 = np.maximum(s_2 - K, 0.0)
         elif self._optionType == FinOptionTypes.EUROPEAN_PUT:
-            payoff_a_1 = np.maximum(K - s_1, 0)
-            payoff_a_2 = np.maximum(K - s_2, 0)
+            payoff_a_1 = np.maximum(K - s_1, 0.0)
+            payoff_a_2 = np.maximum(K - s_2, 0.0)
         else:
             raise FinError("Unknown option type.")
 
