@@ -5,29 +5,29 @@
 import numpy as np
 from scipy import optimize
 
-from ...utils.error import FinError
-from ...utils.date import Date
-from ...utils.helpers import label_to_string
-from ...utils.helpers import check_argument_types, _func_name
-from ...utils.global_vars import gDaysInYear
-from ...market.curves.interpolator import InterpTypes
-from ...market.curves.discount_curve import DiscountCurve
+from ...finutils.FinError import FinError
+from ...finutils.FinDate import FinDate
+from ...finutils.FinHelperFunctions import labelToString
+from ...finutils.FinHelperFunctions import checkArgumentTypes, _funcName
+from ...finutils.FinGlobalVariables import gDaysInYear
+from ...market.curves.FinInterpolate import FinInterpTypes
+from ...market.curves.FinDiscountCurve import FinDiscountCurve
 
 swaptol = 1e-8
 
 ##############################################################################
-# TODO: CHANGE times to df_times
+# TODO: CHANGE times to dfTimes
 ##############################################################################
 
 
 def _f(df, *args):
-    """ Root search objective function for swaps """
+    ''' Root search objective function for swaps '''
     curve = args[0]
-    valuation_date = args[1]
+    valueDate = args[1]
     swap = args[2]
-    num_points = len(curve._times)
-    curve._dfs[num_points - 1] = df
-    v_swap = swap.value(valuation_date, curve, curve, None, 1.0)
+    numPoints = len(curve._times)
+    curve._dfValues[numPoints - 1] = df
+    v_swap = swap.value(valueDate, curve, curve, None, 1.0)
     v_swap /= swap._notional
     return v_swap
 
@@ -35,21 +35,21 @@ def _f(df, *args):
 
 
 def _g(df, *args):
-    """ Root search objective function for swaps """
+    ''' Root search objective function for swaps '''
     curve = args[0]
-    valuation_date = args[1]
+    valueDate = args[1]
     fra = args[2]
-    num_points = len(curve._times)
-    curve._dfs[num_points - 1] = df
-    v_fra = fra.value(valuation_date, curve)
+    numPoints = len(curve._times)
+    curve._dfValues[numPoints - 1] = df
+    v_fra = fra.value(valueDate, curve)
     v_fra /= fra._notional
     return v_fra
 
 ###############################################################################
 
 
-class InflationSwapCurve(DiscountCurve):
-    """ Constructs a discount curve as implied by the prices of Ibor
+class FinInflationSwapCurve(FinDiscountCurve):
+    ''' Constructs a discount curve as implied by the prices of Ibor
     deposits, FRAs and IRS. The curve date is the date on which we are
     performing the valuation based on the information available on the
     curve date. Typically it is the date on which an amount of 1 unit paid
@@ -73,211 +73,212 @@ class InflationSwapCurve(DiscountCurve):
     dates. This approach is non-linear and so requires a solver. Consequently
     it is slower. Its advantage is that we can switch interpolation schemes
     to provide a smoother or other functional curve shape which may have a more
-    economically justifiable shape. However the root search makes it slower."""
+    economically justifiable shape. However the root search makes it slower.'''
 
 ###############################################################################
 
     def __init__(self,
-                 valuation_date: Date,
-                 ibor_deposits: list,
-                 ibor_fras: list,
-                 ibor_swaps: list,
-                 interp_type: InterpTypes = InterpTypes.FLAT_FWD_RATES,
-                 check_refit: bool = False):  # Set to True to test it works
-        """ Create an instance of a Ibor curve given a valuation date and
-        a set of ibor deposits, ibor FRAs and ibor_swaps. Some of these may
+                 valuationDate: FinDate,
+                 iborDeposits: list,
+                 iborFRAs: list,
+                 iborSwaps: list,
+                 interpType: FinInterpTypes = FinInterpTypes.LINEAR_SWAP_RATES,
+                 checkRefit: bool = False):  # Set to True to test it works
+        ''' Create an instance of a FinIbor curve given a valuation date and
+        a set of ibor deposits, ibor FRAs and iborSwaps. Some of these may
         be left None and the algorithm will just use what is provided. An
         interpolation method has also to be provided. The default is to use a
         linear interpolation for swap rates on coupon dates and to then assume
         flat forwards between these coupon dates.
 
         The curve will assign a discount factor of 1.0 to the valuation date.
-        """
+        '''
         raise FinError("DO NOT USE")
+        
+        checkArgumentTypes(getattr(self, _funcName(), None), locals())
 
-        check_argument_types(getattr(self, _func_name(), None), locals())
-
-        self._valuation_date = valuation_date
-        self._validate_inputs(ibor_deposits, ibor_fras, ibor_swaps)
-        self._interp_type = interp_type
-        self._check_refit = check_refit
-        self._build_curve()
+        self._valuationDate = valuationDate
+        self._validateInputs(iborDeposits, iborFRAs, iborSwaps)
+        self._interpType = interpType
+        self._checkRefit = checkRefit
+        self._buildCurve()
 
 ###############################################################################
 
-    def _build_curve(self):
-        """ Build curve based on interpolation. """
-        self._build_curve_using_solver()
+    def _buildCurve(self):
+        ''' Build curve based on interpolation. '''
+        if self._interpType == FinInterpTypes.LINEAR_SWAP_RATES:
+            self._buildCurveLinearSwapRateInterpolation()
+        else:
+            self._buildCurveUsingSolver()
 
 ###############################################################################
 
-    def _validate_inputs(self,
-                         ibor_deposits,
-                         ibor_fras,
-                         ibor_swaps):
-        """ Validate the inputs for each of the Ibor products. """
+    def _validateInputs(self,
+                        iborDeposits,
+                        iborFRAs,
+                        iborSwaps):
+        ''' Validate the inputs for each of the Ibor products. '''
 
-        num_depos = len(ibor_deposits)
-        num_fras = len(ibor_fras)
-        num_swaps = len(ibor_swaps)
+        numDepos = len(iborDeposits)
+        numFRAs = len(iborFRAs)
+        numSwaps = len(iborSwaps)
 
-        if num_depos + num_fras + num_swaps == 0:
+        if numDepos + numFRAs + numSwaps == 0:
             raise FinError("No calibration instruments.")
 
         # Validation of the inputs.
-        if num_depos > 0:
-            for depo in ibor_deposits:
-                startDt = depo._start_date
-                if startDt < self._valuation_date:
+        if numDepos > 0:
+            for depo in iborDeposits:
+                startDt = depo._startDate
+                if startDt < self._valuationDate:
                     raise FinError("First deposit starts before value date.")
 
-            for depo in ibor_deposits:
-                startDt = depo._start_date
-                endDt = depo._maturity_date
+            for depo in iborDeposits:
+                startDt = depo._startDate
+                endDt = depo._maturityDate
                 if startDt >= endDt:
                     raise FinError("First deposit ends on or before it begins")
 
         # Ensure order of depos
-        if num_depos > 1:
-            prev_dt = ibor_deposits[0]._maturity_date
+        if numDepos > 1:
+            prevDt = iborDeposits[0]._maturityDate
 
-            for depo in ibor_deposits[1:]:
-                next_dt = depo._maturity_date
-                if next_dt <= prev_dt:
+            for depo in iborDeposits[1:]:
+                nextDt = depo._maturityDate
+                if nextDt <= prevDt:
                     raise FinError("Deposits must be in increasing maturity")
-                prev_dt = next_dt
+                prevDt = nextDt
 
         # Ensure that valuation date is on or after first deposit start date
-        if num_depos > 1:
-            if ibor_deposits[0]._start_date > self._valuation_date:
-                raise FinError(
-                    "Valuation date must not be before first deposit settles.")
+        if numDepos > 1:
+            if iborDeposits[0]._startDate > self._valuationDate:
+                raise FinError("Valuation date must not be before first deposit settles.")
 
-        if num_fras > 0:
-            for fra in ibor_fras:
-                startDt = fra._start_date
-                if startDt <= self._valuation_date:
+        if numFRAs > 0:
+            for fra in iborFRAs:
+                startDt = fra._startDate
+                if startDt <= self._valuationDate:
                     raise FinError("FRAs starts before valuation date")
 
-        if num_fras > 1:
-            prev_dt = ibor_fras[0]._maturity_date
-            for fra in ibor_fras[1:]:
-                next_dt = fra._maturity_date
-                if next_dt <= prev_dt:
+        if numFRAs > 1:
+            prevDt = iborFRAs[0]._maturityDate
+            for fra in iborFRAs[1:]:
+                nextDt = fra._maturityDate
+                if nextDt <= prevDt:
                     raise FinError("FRAs must be in increasing maturity")
-                prev_dt = next_dt
+                prevDt = nextDt
 
-        if num_swaps > 0:
-            for swap in ibor_swaps:
-                startDt = swap._start_date
-                if startDt < self._valuation_date:
+        if numSwaps > 0:
+            for swap in iborSwaps:
+                startDt = swap._startDate
+                if startDt < self._valuationDate:
                     raise FinError("Swaps starts before valuation date.")
 
-        if num_swaps > 1:
+        if numSwaps > 1:
 
             # Swaps must all start on the same date for the bootstrap
-            startDt = ibor_swaps[0]._start_date
-            for swap in ibor_swaps[1:]:
-                nextStartDt = swap._start_date
+            startDt = iborSwaps[0]._startDate
+            for swap in iborSwaps[1:]:
+                nextStartDt = swap._startDate
                 if nextStartDt != startDt:
                     raise FinError("Swaps must all have same start date.")
 
             # Swaps must be increasing in tenor/maturity
-            prev_dt = ibor_swaps[0]._maturity_date
-            for swap in ibor_swaps[1:]:
-                next_dt = swap._maturity_date
-                if next_dt <= prev_dt:
+            prevDt = iborSwaps[0]._maturityDate
+            for swap in iborSwaps[1:]:
+                nextDt = swap._maturityDate
+                if nextDt <= prevDt:
                     raise FinError("Swaps must be in increasing maturity")
-                prev_dt = next_dt
+                prevDt = nextDt
 
-            # Swaps must have same cash flows for bootstrap to work
-            longestSwap = ibor_swaps[-1]
+            # Swaps must have same cashflows for bootstrap to work
+            longestSwap = iborSwaps[-1]
             longestSwapCpnDates = longestSwap._adjustedFixedDates
-            for swap in ibor_swaps[0:-1]:
+            for swap in iborSwaps[0:-1]:
                 swapCpnDates = swap._adjustedFixedDates
-                num_flows = len(swapCpnDates)
-                for iFlow in range(0, num_flows):
+                numFlows = len(swapCpnDates)
+                for iFlow in range(0, numFlows):
                     if swapCpnDates[iFlow] != longestSwapCpnDates[iFlow]:
-                        raise FinError(
-                            "Swap coupons are not on the same date grid.")
+                        raise FinError("Swap coupons are not on the same date grid.")
 
         #######################################################################
         # Now we have ensure they are in order check for overlaps and the like
         #######################################################################
 
-        lastDepositMaturityDate = Date(1, 1, 1900)
-        firstFRAMaturityDate = Date(1, 1, 1900)
-        lastFRAMaturityDate = Date(1, 1, 1900)
+        lastDepositMaturityDate = FinDate(1, 1, 1900)
+        firstFRAMaturityDate = FinDate(1, 1, 1900)
+        lastFRAMaturityDate = FinDate(1, 1, 1900)
 
-        if num_depos > 0:
-            lastDepositMaturityDate = ibor_deposits[-1]._maturity_date
+        if numDepos > 0:
+            lastDepositMaturityDate = iborDeposits[-1]._maturityDate
 
-        if num_fras > 0:
-            firstFRAMaturityDate = ibor_fras[0]._maturity_date
-            lastFRAMaturityDate = ibor_fras[-1]._maturity_date
+        if numFRAs > 0:
+            firstFRAMaturityDate = iborFRAs[0]._maturityDate
+            lastFRAMaturityDate = iborFRAs[-1]._maturityDate
 
-        if num_swaps > 0:
-            firstSwapMaturityDate = ibor_swaps[0]._maturity_date
+        if numSwaps > 0:
+            firstSwapMaturityDate = iborSwaps[0]._maturityDate
 
-        if num_depos > 0 and num_fras > 0:
+        if numDepos > 0 and numFRAs > 0:
             if firstFRAMaturityDate <= lastDepositMaturityDate:
                 print("FRA Maturity Date:", firstFRAMaturityDate)
                 print("Last Deposit Date:", lastDepositMaturityDate)
                 raise FinError("First FRA must end after last Deposit")
 
-        if num_fras > 0 and num_swaps > 0:
+        if numFRAs > 0 and numSwaps > 0:
             if firstSwapMaturityDate <= lastFRAMaturityDate:
                 raise FinError("First Swap must mature after last FRA")
 
         # Now determine which instruments are used
-        self._usedDeposits = ibor_deposits
-        self._usedFRAs = ibor_fras
-        self._usedSwaps = ibor_swaps
-        self._day_count_type = None
+        self._usedDeposits = iborDeposits
+        self._usedFRAs = iborFRAs
+        self._usedSwaps = iborSwaps
+        self._dayCountType = None
 
 ###############################################################################
 
-    def _build_curve_using_solver(self):
-        """ Construct the discount curve using a bootstrap approach. This is
+    def _buildCurveUsingSolver(self):
+        ''' Construct the discount curve using a bootstrap approach. This is
         the non-linear slower method that allows the user to choose a number
         of interpolation approaches between the swap rates and other rates. It
-        involves the use of a solver. """
+        involves the use of a solver. '''
 
         self._times = np.array([])
-        self._dfs = np.array([])
+        self._dfValues = np.array([])
 
         # time zero is now.
         tmat = 0.0
         dfMat = 1.0
         self._times = np.append(self._times, 0.0)
-        self._dfs = np.append(self._dfs, dfMat)
+        self._dfValues = np.append(self._dfValues, dfMat)
 
         for depo in self._usedDeposits:
-            dfSettle = self.df(depo._start_date)
-            dfMat = depo._maturity_df() * dfSettle
-            tmat = (depo._maturity_date - self._valuation_date) / gDaysInYear
+            dfSettle = self.df(depo._startDate)
+            dfMat = depo._maturityDf() * dfSettle
+            tmat = (depo._maturityDate - self._valuationDate) / gDaysInYear
             self._times = np.append(self._times, tmat)
-            self._dfs = np.append(self._dfs, dfMat)
+            self._dfValues = np.append(self._dfValues, dfMat)
 
         oldtmat = tmat
 
         for fra in self._usedFRAs:
 
-            tset = (fra._start_date - self._valuation_date) / gDaysInYear
-            tmat = (fra._maturity_date - self._valuation_date) / gDaysInYear
+            tset = (fra._startDate - self._valuationDate) / gDaysInYear
+            tmat = (fra._maturityDate - self._valuationDate) / gDaysInYear
 
             # if both dates are after the previous FRA/FUT then need to
             # solve for 2 discount factors simultaneously using root search
 
             if tset < oldtmat and tmat > oldtmat:
-                dfMat = fra.maturity_df(self)
+                dfMat = fra.maturityDf(self)
                 self._times = np.append(self._times, tmat)
-                self._dfs = np.append(self._dfs, dfMat)
+                self._dfValues = np.append(self._dfValues, dfMat)
             else:
                 self._times = np.append(self._times, tmat)
-                self._dfs = np.append(self._dfs, dfMat)
+                self._dfValues = np.append(self._dfValues, dfMat)
 
-                argtuple = (self, self._valuation_date, fra)
+                argtuple = (self, self._valuationDate, fra)
                 dfMat = optimize.newton(_g, x0=dfMat, fprime=None,
                                         args=argtuple, tol=swaptol,
                                         maxiter=50, fprime2=None)
@@ -285,75 +286,75 @@ class InflationSwapCurve(DiscountCurve):
         for swap in self._usedSwaps:
             # I use the lastPaymentDate in case a date has been adjusted fwd
             # over a holiday as the maturity date is usually not adjusted CHECK
-            maturity_date = swap._lastPaymentDate
-            tmat = (maturity_date - self._valuation_date) / gDaysInYear
+            maturityDate = swap._lastPaymentDate
+            tmat = (maturityDate - self._valuationDate) / gDaysInYear
 
             self._times = np.append(self._times, tmat)
-            self._dfs = np.append(self._dfs, dfMat)
+            self._dfValues = np.append(self._dfValues, dfMat)
 
-            argtuple = (self, self._valuation_date, swap)
+            argtuple = (self, self._valuationDate, swap)
 
             dfMat = optimize.newton(_f, x0=dfMat, fprime=None, args=argtuple,
                                     tol=swaptol, maxiter=50, fprime2=None,
                                     full_output=False)
 
-        if self._check_refit is True:
-            self._check_refits(1e-10, swaptol, 1e-5)
+        if self._checkRefit is True:
+            self._checkRefits(1e-10, swaptol, 1e-5)
 
 ###############################################################################
 
-    def _build_curve_linear_swap_rate_interpolation(self):
-        """ Construct the discount curve using a bootstrap approach. This is
+    def _buildCurveLinearSwapRateInterpolation(self):
+        ''' Construct the discount curve using a bootstrap approach. This is
         the linear swap rate method that is fast and exact as it does not
-        require the use of a solver. It is also market standard. """
+        require the use of a solver. It is also market standard. '''
 
         self._times = np.array([])
-        self._dfs = np.array([])
+        self._dfValues = np.array([])
 
         # time zero is now.
         tmat = 0.0
         dfMat = 1.0
         self._times = np.append(self._times, 0.0)
-        self._dfs = np.append(self._dfs, dfMat)
+        self._dfValues = np.append(self._dfValues, dfMat)
 
         for depo in self._usedDeposits:
-            dfSettle = self.df(depo._start_date)
-            dfMat = depo._maturity_df() * dfSettle
-            tmat = (depo._maturity_date - self._valuation_date) / gDaysInYear
+            dfSettle = self.df(depo._startDate)
+            dfMat = depo._maturityDf() * dfSettle
+            tmat = (depo._maturityDate - self._valuationDate) / gDaysInYear
             self._times = np.append(self._times, tmat)
-            self._dfs = np.append(self._dfs, dfMat)
+            self._dfValues = np.append(self._dfValues, dfMat)
 
         oldtmat = tmat
 
         for fra in self._usedFRAs:
 
-            tset = (fra._start_date - self._valuation_date) / gDaysInYear
-            tmat = (fra._maturity_date - self._valuation_date) / gDaysInYear
+            tset = (fra._startDate - self._valuationDate) / gDaysInYear
+            tmat = (fra._maturityDate - self._valuationDate) / gDaysInYear
 
             # if both dates are after the previous FRA/FUT then need to
             # solve for 2 discount factors simultaneously using root search
 
             if tset < oldtmat and tmat > oldtmat:
-                dfMat = fra.maturity_df(self)
+                dfMat = fra.maturityDf(self)
                 self._times = np.append(self._times, tmat)
-                self._dfs = np.append(self._dfs, dfMat)
+                self._dfValues = np.append(self._dfValues, dfMat)
             else:
                 self._times = np.append(self._times, tmat)
-                self._dfs = np.append(self._dfs, dfMat)
+                self._dfValues = np.append(self._dfValues, dfMat)
 
-                argtuple = (self, self._valuation_date, fra)
+                argtuple = (self, self._valuationDate, fra)
                 dfMat = optimize.newton(_g, x0=dfMat, fprime=None,
                                         args=argtuple, tol=swaptol,
                                         maxiter=50, fprime2=None)
 
         if len(self._usedSwaps) == 0:
-            if self._check_refit is True:
-                self._check_refits(1e-10, swaptol, 1e-5)
+            if self._checkRefit is True:
+                self._checkRefits(1e-10, swaptol, 1e-5)
             return
 
 #        print("CURVE SO FAR")
 #        print(self._times)
-#        print(self._dfs)
+#        print(self._dfValues)
 
         #######################################################################
         # ADD SWAPS TO CURVE
@@ -361,50 +362,50 @@ class InflationSwapCurve(DiscountCurve):
 
         # Find where the FRAs and Depos go up to as this bit of curve is done
         foundStart = False
-        lastDate = self._valuation_date
+        lastDate = self._valuationDate
         if len(self._usedDeposits) != 0:
-            lastDate = self._usedDeposits[-1]._maturity_date
+            lastDate = self._usedDeposits[-1]._maturityDate
 
         if len(self._usedFRAs) != 0:
-            lastDate = self._usedFRAs[-1]._maturity_date
+            lastDate = self._usedFRAs[-1]._maturityDate
 
         # We use the longest swap assuming it has a superset of ALL of the
         # swap flow dates used in the curve construction
         longestSwap = self._usedSwaps[-1]
         couponDates = longestSwap._adjustedFixedDates
-        num_flows = len(couponDates)
+        numFlows = len(couponDates)
 
         # Find where first coupon without discount factor starts
-        start_index = 0
-        for i in range(0, num_flows):
+        startIndex = 0
+        for i in range(0, numFlows):
             if couponDates[i] > lastDate:
-                start_index = i
+                startIndex = i
                 foundStart = True
                 break
 
         if foundStart is False:
             raise FinError("Found start is false. Swaps payments inside FRAs")
 
-        swap_rates = []
+        swapRates = []
         swapTimes = []
 
         # I use the last coupon date for the swap rate interpolation as this
         # may be different from the maturity date due to a holiday adjustment
         # and the swap rates need to align with the coupon payment dates
         for swap in self._usedSwaps:
-            swap_rate = swap._fixed_coupon
-            maturity_date = swap._adjustedFixedDates[-1]
-            tswap = (maturity_date - self._valuation_date) / gDaysInYear
+            swapRate = swap._fixedCoupon
+            maturityDate = swap._adjustedFixedDates[-1]
+            tswap = (maturityDate - self._valuationDate) / gDaysInYear
             swapTimes.append(tswap)
-            swap_rates.append(swap_rate)
+            swapRates.append(swapRate)
 
         interpolatedSwapRates = [0.0]
         interpolatedSwapTimes = [0.0]
 
         for dt in couponDates[1:]:
-            swapTime = (dt - self._valuation_date) / gDaysInYear
-            swap_rate = np.interp(swapTime, swapTimes, swap_rates)
-            interpolatedSwapRates.append(swap_rate)
+            swapTime = (dt - self._valuationDate) / gDaysInYear
+            swapRate = np.interp(swapTime, swapTimes, swapRates)
+            interpolatedSwapRates.append(swapRate)
             interpolatedSwapTimes.append(swapTime)
 
         # Do I need this line ?
@@ -413,108 +414,108 @@ class InflationSwapCurve(DiscountCurve):
 #        print("Interpolated swap times:", interpolatedSwapTimes)
 #        print("Interpolated swap rates:", interpolatedSwapRates)
 
-        accrual_factors = longestSwap._fixed_year_fracs
+        accrualFactors = longestSwap._fixedYearFracs
 
         acc = 0.0
         df = 1.0
         pv01 = 0.0
-        dfSettle = self.df(longestSwap._start_date)
+        dfSettle = self.df(longestSwap._startDate)
 #        print("SETTLE", dfSettle)
 
-        for i in range(1, start_index):
+        for i in range(1, startIndex):
             dt = couponDates[i]
             df = self.df(dt)
-            acc = accrual_factors[i-1]
+            acc = accrualFactors[i-1]
             pv01 += acc * df
 #            print("BEFORE", i, dt, df, acc, pv01)
 
-        for i in range(start_index, num_flows):
+        for i in range(startIndex, numFlows):
 
             dt = couponDates[i]
-            tmat = (dt - self._valuation_date) / gDaysInYear
-            swap_rate = interpolatedSwapRates[i]
-            acc = accrual_factors[i-1]
-            pv01End = (acc * swap_rate + 1.0)
+            tmat = (dt - self._valuationDate) / gDaysInYear
+            swapRate = interpolatedSwapRates[i]
+            acc = accrualFactors[i-1]
+            pv01End = (acc * swapRate + 1.0)
 
-            dfMat = (dfSettle - swap_rate * pv01) / pv01End
+            dfMat = (dfSettle - swapRate * pv01) / pv01End
 
 #            print("IN: %12s %12.10f %12.10f %12.10f %12.10f OUT: %14.12f" %
-#                  (dt, swap_rate, acc, pv01, pv01End, dfMat))
+#                  (dt, swapRate, acc, pv01, pv01End, dfMat))
 
             self._times = np.append(self._times, tmat)
-            self._dfs = np.append(self._dfs, dfMat)
+            self._dfValues = np.append(self._dfValues, dfMat)
 
             pv01 += acc * dfMat
 
 #        print(self._times)
-#        print(self._dfs)
+#        print(self._dfValues)
 
-        if self._check_refit is True:
-            self._check_refits(1e-10, swaptol, 1e-5)
+        if self._checkRefit is True:
+            self._checkRefits(1e-10, swaptol, 1e-5)
 
 ###############################################################################
 
-    def _check_refits(self, depoTol, fraTol, swapTol):
-        """ Ensure that the Ibor curve refits the calibration instruments. """
+    def _checkRefits(self, depoTol, fraTol, swapTol):
+        ''' Ensure that the Ibor curve refits the calibration instruments. '''
         for depo in self._usedDeposits:
-            v = depo.value(self._valuation_date, self) / depo._notional
+            v = depo.value(self._valuationDate, self) / depo._notional
             if abs(v - 1.0) > depoTol:
                 print("Value", v)
                 raise FinError("Deposit not repriced.")
 
         for fra in self._usedFRAs:
-            v = fra.value(self._valuation_date, self) / fra._notional
+            v = fra.value(self._valuationDate, self) / fra._notional
             if abs(v) > fraTol:
                 print("Value", v)
                 raise FinError("FRA not repriced.")
 
         for swap in self._usedSwaps:
             # We value it as of the start date of the swap
-            v = swap.value(swap._start_date, self, self, None, principal=0.0)
+            v = swap.value(swap._startDate, self, self, None, principal=0.0)
             v = v / swap._notional
 #            print("REFIT SWAP VALUATION:", swap._adjustedMaturityDate, v)
             if abs(v) > swapTol:
-                print("Swap with maturity " + str(swap._maturity_date)
+                print("Swap with maturity " + str(swap._maturityDate)
                       + " Not Repriced. Has Value", v)
-                swap.print_fixed_leg_pv()
-                swap.print_float_leg_pv()
+                swap.printFixedLegPV()
+                swap.printFloatLegPV()
                 raise FinError("Swap not repriced.")
 
 ###############################################################################
 
     def __repr__(self):
-        """ Print out the details of the Ibor curve. """
+        ''' Print out the details of the Ibor curve. '''
 
-        s = label_to_string("OBJECT TYPE", type(self).__name__)
-        s += label_to_string("VALUATION DATE", self._valuation_date)
+        s = labelToString("OBJECT TYPE", type(self).__name__)
+        s += labelToString("VALUATION DATE", self._valuationDate)
 
         for depo in self._usedDeposits:
-            s += label_to_string("DEPOSIT", "")
+            s += labelToString("DEPOSIT", "")
             s += depo.__repr__()
 
         for fra in self._usedFRAs:
-            s += label_to_string("FRA", "")
+            s += labelToString("FRA", "")
             s += fra.__repr__()
 
         for swap in self._usedSwaps:
-            s += label_to_string("SWAP", "")
+            s += labelToString("SWAP", "")
             s += swap.__repr__()
 
-        num_points = len(self._times)
+        numPoints = len(self._times)
 
-        s += label_to_string("INTERP TYPE", self._interp_type)
+        s += labelToString("INTERP TYPE", self._interpType)
 
-        s += label_to_string("GRID TIMES", "GRID DFS")
-        for i in range(0, num_points):
-            s += label_to_string("% 10.6f" % self._times[i],
-                                 "%12.10f" % self._dfs[i])
+        s += labelToString("GRID TIMES", "GRID DFS")
+        for i in range(0, numPoints):
+            s += labelToString("% 10.6f" % self._times[i],
+                               "%12.10f" % self._dfValues[i])
 
         return s
 
 ###############################################################################
 
     def _print(self):
-        """ Simple print function for backward compatibility. """
+        ''' Simple print function for backward compatibility. '''
         print(self)
 
 ###############################################################################
